@@ -7,6 +7,7 @@ from kks.cmd.auth import auth
 from kks.cmd.convert import convert
 from kks.cmd.deadlines import deadlines
 from kks.cmd.gen import gen
+from kks.cmd.get import get
 from kks.cmd.hide import hide, unhide
 from kks.cmd.init import init
 from kks.cmd.lint import lint
@@ -51,6 +52,7 @@ cli.add_command(status, group=Commands.ejudge)
 cli.add_command(top, group=Commands.ejudge)
 cli.add_command(deadlines, group=Commands.ejudge)
 cli.add_command(submit, group=Commands.ejudge)
+cli.add_command(get, group=Commands.ejudge)
 
 cli.add_command(lint, group=Commands.solution)
 cli.add_command(build, group=Commands.solution)
