@@ -6,8 +6,8 @@ from tqdm import tqdm
 from kks.binary import compile_solution, run_solution
 from kks.util.script import find_script
 from kks.util.testing import TestSource, VirtualTestSequence, RunOptions, Test
-from kks.util.common import get_solution_directory, format_file, find_test_output, test_number_to_name, \
-    find_test_pairs, print_diff
+from kks.util.common import get_solution_directory, format_file, find_test_output, \
+    test_number_to_name, find_test_pairs, print_diff
 
 
 @click.command(name='test', short_help='Test solutions')
@@ -78,7 +78,11 @@ def test_(target, verbose, tests, test_range, files, sample,
         run_tests(binary, tests, options)
     else:
         generator = find_script(directory, 'gen', default=generator)
+        if generator is None:
+            return
         solution = find_script(directory, 'solve', default=solution)
+        if solution is None:
+            return
         with TestSource(generator, solution, options) as test_source:
             if test_range:
                 l, r = sorted(test_range)
@@ -87,7 +91,7 @@ def test_(target, verbose, tests, test_range, files, sample,
             if not tests and not test_range:
                 test_range = range(1, 101)
 
-            all_tests = sorted(set(tests) | set(test_range))
+            all_tests = sorted(set(tests) | set(test_range or []))
 
             tests = VirtualTestSequence(test_source, all_tests)
 
@@ -118,7 +122,9 @@ def find_tests_to_run(directory, files, tests, test_range, sample):
                 return None
             output_file = find_test_output(input_file)
             if output_file is None:
-                click.secho(f'No output for test file {format_file(input_file)}', fg='yellow', err=True)
+                click.secho(
+                    f'No output for test file {format_file(input_file)}', fg='yellow', err=True
+                )
                 continue
             result.add(Test.from_file(input_file.stem, input_file, output_file))
 
