@@ -1,17 +1,15 @@
 import difflib
 import pickle
-from abc import ABCMeta
 from functools import wraps
 from pathlib import Path
 from time import time, sleep
 
 import click
 
-from kks.ejudge import AuthData
 
-
-class Singleton(ABCMeta):
+class Singleton(type):
     _instances = {}
+
     def __call__(cls, *args, **kwargs):
         if cls not in cls._instances:
             cls._instances[cls] = super(Singleton, cls).__call__(*args, **kwargs)
