@@ -1,20 +1,19 @@
 import json
-import pickle
-import re
 from base64 import b64decode
+from typing import Optional
+from urllib.parse import parse_qs, urlencode, urlsplit, urlunsplit
 
 import click
 
 from kks import __version__
-from kks.ejudge import AuthData, Links, get_contest_url
-from kks.util.common import config_directory
+from kks.ejudge import AuthData, Links, Page, get_contest_url
 from kks.errors import EjudgeUnavailableError, AuthError, APIError
 from kks.util.storage import Config, PickleStorage
 
 
 def load_auth_data():
     auth = Config().auth
-    if auth.login and auth.contest:
+    if auth.login:
         return AuthData(auth.login, auth.contest, auth.password)
     return None
 
@@ -23,10 +22,10 @@ def save_auth_data(auth_data, store_password=True):
     config = Config()
     config.auth.login = auth_data.login
     config.auth.contest = auth_data.contest_id
-
     if store_password and auth_data.password is not None:
         config.auth.password = auth_data.password
-
+    else:
+        del config.auth.password
     config.save()
 
 
@@ -39,6 +38,7 @@ def check_response(resp):
 class RunStatus:
     """A (very) limited wrapper class for responses from "run-status-json" method"""
 
+    # TODO use enum?
     COMPILING = 98  # from github.com/blackav/ejudge-fuse
     COMPILED = 97
     RUNNING = 96
@@ -109,7 +109,6 @@ class RunStatus:
             except Exception:
                 self.compiler_output = 'Cannot decode compiler output: {data}'
 
-
     def is_testing(self):
         return self.status >= 95 and self.status <= 99
 
@@ -124,7 +123,10 @@ class RunStatus:
             return f"{test['num']} - {self.get_description(test['status'])}"
 
         if failed_only:
-            test_results = '\n'.join(map(test_descr, [test for test in self.tests if test['status'] not in [self.OK, self.SKIPPED]]))
+            test_results = '\n'.join(
+                test_descr(test)
+                for test in self.tests if test['status'] not in [self.OK, self.SKIPPED]
+            )
         else:
             test_results = '\n'.join(map(test_descr, self.tests))
         return f'{self}\n{test_results}'
@@ -166,7 +168,9 @@ class API:
         except ValueError as e:
             if not need_json:
                 return resp.content
-            raise APIError(f'Invalid response. resp={resp.content}, err={e}', APIError.INVALID_RESPONSE)
+            raise APIError(
+                f'Invalid response. resp={resp.content}, err={e}', APIError.INVALID_RESPONSE
+            )
 
         # if a submission is a valid JSON file, then api.download_run will fail
         if not need_json or not data['ok']:
@@ -190,7 +194,7 @@ class API:
 
         return self._request(url, need_json, **kwargs)
 
-    def auth(self, creds):
+    def auth(self, creds: AuthData):
         """get new sids"""
         # NOTE is 1step auth possible?
 
@@ -270,8 +274,6 @@ class API:
 
 
 class EjudgeSession:
-    sid_regex = re.compile(r'SID=([0-9a-f]{16}|__SID__)')
-
     def __init__(self, auth=True):
         import requests
         self.http = requests.session()
@@ -288,9 +290,14 @@ class EjudgeSession:
         if auth_data is None:  # auto-auth
             auth_data = load_auth_data()
             if auth_data is None:
-                raise AuthError('Auth data is not found, please use "kks auth" to log in', fg='yellow')
+                raise AuthError(
+                    'Auth data is not found, please use "kks auth" to log in', fg='yellow'
+                )
 
-            click.secho('Ejudge session is missing or invalid, trying to auth with saved data', fg='yellow', err=True)
+            click.secho(
+                'Ejudge session is missing or invalid, trying to auth with saved data',
+                fg='yellow', err=True
+            )
             if auth_data.password is None:
                 auth_data.password = click.prompt('Password', hide_input=True)
 
@@ -319,7 +326,8 @@ class EjudgeSession:
         """
         Create an API wrapper with (EJ)SID from this session
         If cookies are outdated, api requests will raise an APIError
-        If api is used before any session requests are performed, use EjudgeSession.with_auth for the first request
+        If api is used before any session requests are performed,
+        use EjudgeSession.with_auth for the first request/
         Example:
         >>> api = session.api()
         >>> problem = session.with_auth(api.problem_status, 123)
@@ -329,8 +337,12 @@ class EjudgeSession:
         return API(self.sids)
 
     def with_auth(self, api_method, *args, **kwargs):
-        """
-        api_method should only a method of API object that was created with .api() method of this instance
+        """Calls the API method, updates auth data if needed.
+
+        Args:
+            api_method: A method of an API object
+                that was returned from `self.api()`.
+                If any other API object is used, results are undefined.
         """
         try:
             return api_method(*args, **kwargs)
@@ -340,8 +352,12 @@ class EjudgeSession:
                 return api_method(*args, **kwargs)
             raise e
 
+    @staticmethod
+    def needs_auth(url):
+        return 'SID' in parse_qs(urlsplit(url).query)
+
     def _update_sids(self, url):
-        self.sids.sid = EjudgeSession.sid_regex.search(url).group(1)
+        self.sids.sid = parse_qs(urlsplit(url).query)['SID'][0]
         self.sids.ejsid = self.http.cookies['EJSID']
 
     def _store_sids(self):
@@ -352,19 +368,41 @@ class EjudgeSession:
         with self._storage.load() as storage:
             return storage.get('sids')
 
-    def modify_url(self, url):
-        return re.sub(EjudgeSession.sid_regex, f'SID={self.sids.sid}', url, count=1)
-
     def _request(self, method, url, *args, **kwargs):
-        response = method(self.modify_url(url), *args, **kwargs)
+        # NOTE params should only be passed as a keyword argument
+        params = kwargs.get('params', {}).copy()
+        # If SID is included in the url, move it to params
+        parts = urlsplit(url)
+        query = parse_qs(parts.query)
+        if 'SID' in query:
+            params['SID'] = query.pop('SID')[0]
+            url = urlunsplit(parts._replace(query=urlencode(query, doseq=True)))
+        params['SID'] = self.sids.sid
+        page_id: Optional[Page] = kwargs.pop('page_id', None)
+        if page_id is not None:
+            params['action'] = page_id.value
+        kwargs['params'] = params
+
+        response = method(url, *args, **kwargs)
         check_response(response)
-        if 'Invalid session' in response.text:
+        # the requested page may contain binary data (e.g. problem attachments)
+        if b'Invalid session' in response.content:
             self.auth()
-            response = method(self.modify_url(url), *args, **kwargs)
+            params['SID'] = self.sids.sid
+            response = method(url, *args, **kwargs)
         return response
 
     def get(self, url, *args, **kwargs):
+        if args:
+            kwargs['params'] = args[0]
+            args = args[1:]
         return self._request(self.http.get, url, *args, **kwargs)
 
     def post(self, url, *args, **kwargs):
         return self._request(self.http.post, url, *args, **kwargs)
+
+    def get_page(self, page_id: Page, *args, **kwargs):
+        return self.get(Links.WEB_CLIENT_ROOT, *args, page_id=page_id, **kwargs)
+
+    def post_page(self, page_id: Page, *args, **kwargs):
+        return self.post(Links.WEB_CLIENT_ROOT, *args, page_id=page_id, **kwargs)
